Rect

Struct Rect 

pub struct Rect { /* private fields */ }
Rectangle defining an area

Implementations

Source

impl Rect

pub const fn subrect( &self, x: TSize, y: TSize, width: TSize, height: TSize, ) -> Result<Rect, RectError>

Creates a new rect which is relative to the base coordinates of {0, 0} This will be relative to the base and check their bounds

pub fn subrect2(&self, offset: TPoint, size: TPoint) -> Result<Rect, RectError>

Same as Self::subrect but with Vector2Ds as arguments

pub const fn start(&self) -> TPoint

Start coordinates

pub const fn size(&self) -> TPoint

Size of the rectangle

pub const fn end(&self) -> TPoint

End coordinates (start + end)

pub fn overlaps(&self, other: &Self) -> bool

Checks if the two rects overlap

pub fn split( &self, orientation: Orientation, ratio: Percent, padding: TSize, ) -> Result<SplitRect, RectError>

Splits the rect into two seperate rects at the given orientation’s line ratio determines the size of the first rect, the other rect will occupy the remaining size ‘padding’ might be adjusted towards 0 in case one of the rect’s area would be 0 => Thus this method will always produce rects with a width/height of 1

pub const fn area(&self) -> TSize

Returns the inner area