Enum Direction
Source pub enum Direction {
Up,
Down,
Left,
Right,
}
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Gets the type name of self
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns
true if the boxed type is the same as
T.
Read more
Forward to the method defined on the type Any.
Forward to the method defined on the type Any.
Returns the argument unchanged.
A constant of the type witness
Proof that Self is the same type as Self::Type,
provides methods for casting between Self and Self::Type.
The same type as Self,
used to emulate type equality bounds (T == U)
with associated type equality constraints
(T: Identity<Type = U>).
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.