Combobox

Struct Combobox 

pub struct Combobox<T: PartialEq + 'static> { /* private fields */ }
Combobox contains a list of values of which one can be selected The selected value can be changed by using the Left and Right buttons Focus highlights the Combobox’s text

Design (Border is part of the component):

┌─┬─────────────┬─┐
│<│ Text [2/28] │>│
└─┴─────────────┴─┘

Implementations

Source

impl<T: PartialEq> Combobox<T>

pub const INDICATOR_LEFT: Grapheme = ScrollViewer::ARROW_LEFT

pub const INDICATOR_RIGHT: Grapheme = ScrollViewer::ARROW_RIGHT

pub const DEFAULT_BORDER: BorderKind = BorderKind::Solid

pub fn default_callback(_: &mut Self)

pub fn default_key_handler(&mut self, event: &mut WindowEvent)

pub fn set_key_handler(&mut self, f: ComboboxKeyHandler<T>)

pub fn set_selection_changed_callback<F: Fn(&mut Self) + 'static>( &mut self, callback: F, )

Examples found in repository?
examples/stackpanel.rs (lines 74-77)
52	fn default() -> Self {
53		let label = WindowFactory::create::<Label>();
54		label
55			.borrow_mut()
56			.set_text("Please enter a valid number (x ∈ ℕ):");
57		let button = WindowFactory::create::<Button>();
58		button.borrow_mut().set_text("Press to increment:");
59		button.borrow_mut().set_border(BorderKind::Solid.into());
60		let mut cb: Combobox<u8> = Combobox::default();
61		for v in [1, 2, 4] {
62			cb.add_item(DisplayValue::new(v, format!("Increment by {}", v)));
63		}
64		let cb = Rc::new(RefCell::new(cb));
65		let combobox = cb.clone();
66		let numeric = WindowFactory::create::<Numeric>();
67		numeric.borrow_mut().set_base(Radix::Hexadecimal);
68		numeric.borrow_mut().set_min_range(8);
69		numeric.borrow_mut().set_max_range(64);
70		numeric.borrow_mut().set_focus_color(Some(Color::Cyan));
71		let nc = numeric.clone();
72		combobox
73			.borrow_mut()
74			.set_selection_changed_callback(move |cb| {
75				let mut brw = nc.borrow_mut();
76				brw.set_stepcount(*cb.get_value().unwrap().value())
77			});
78
79		let stackpanel = WindowFactory::create::<Stackpanel>();
80		stackpanel.borrow_mut().set_border(BorderKind::Solid.into());
81		stackpanel.borrow_mut().add_item(label);
82		stackpanel.borrow_mut().add_item(numeric);
83		stackpanel.borrow_mut().add_item(cb);
84
85		Self {
86			uid: WindowUID::new(),
87			stackpanel,
88			running: true,
89		}
90	}
pub fn get_value(&self) -> Option<&DisplayValue<T>>

Examples found in repository?
examples/stackpanel.rs (line 76)
52	fn default() -> Self {
53		let label = WindowFactory::create::<Label>();
54		label
55			.borrow_mut()
56			.set_text("Please enter a valid number (x ∈ ℕ):");
57		let button = WindowFactory::create::<Button>();
58		button.borrow_mut().set_text("Press to increment:");
59		button.borrow_mut().set_border(BorderKind::Solid.into());
60		let mut cb: Combobox<u8> = Combobox::default();
61		for v in [1, 2, 4] {
62			cb.add_item(DisplayValue::new(v, format!("Increment by {}", v)));
63		}
64		let cb = Rc::new(RefCell::new(cb));
65		let combobox = cb.clone();
66		let numeric = WindowFactory::create::<Numeric>();
67		numeric.borrow_mut().set_base(Radix::Hexadecimal);
68		numeric.borrow_mut().set_min_range(8);
69		numeric.borrow_mut().set_max_range(64);
70		numeric.borrow_mut().set_focus_color(Some(Color::Cyan));
71		let nc = numeric.clone();
72		combobox
73			.borrow_mut()
74			.set_selection_changed_callback(move |cb| {
75				let mut brw = nc.borrow_mut();
76				brw.set_stepcount(*cb.get_value().unwrap().value())
77			});
78
79		let stackpanel = WindowFactory::create::<Stackpanel>();
80		stackpanel.borrow_mut().set_border(BorderKind::Solid.into());
81		stackpanel.borrow_mut().add_item(label);
82		stackpanel.borrow_mut().add_item(numeric);
83		stackpanel.borrow_mut().add_item(cb);
84
85		Self {
86			uid: WindowUID::new(),
87			stackpanel,
88			running: true,
89		}
90	}
pub fn set_border_fg(&mut self, color: Option<Color>)

pub fn set_border_bg(&mut self, color: Option<Color>)

pub fn select_next(&mut self)

Selects the next possible element

pub fn select_previous(&mut self)

Selects the previous possible element