DataGrid

Struct DataGrid 

pub struct DataGrid { /* private fields */ }
A grid-based component to dynamically present many different values (of possibly different datatypes) Design:

 Row | Column1 | Column2 | Column3 |
─────┼─────────┼─────────┼─────────|
  1  | <NULL>  |  true   | textabc |
  2  | <NULL>  |  false  | <EMPTY> |
  3  |  1234   |  true   |   abc   |

Implementations

Source

impl DataGrid

pub fn new() -> Self

pub fn default_callback(_: &mut Self)

pub fn default_key_handler(&mut self, event: &mut WindowEvent)

pub fn set_key_handler(&mut self, f: DataGridKeyHandler)

pub fn set_callback<F: Fn(&mut Self) + 'static>(&mut self, callback: F)

pub fn set_radix(&mut self, radix: Radix)

pub fn set_selection_color(&mut self, color: Option<Color>)

Examples found in repository?
examples/datagrid.rs (line 113)
107	fn default() -> Self {
108		let datagrid = WindowFactory::create::<DataGrid>();
109		{
110			let mut brw = datagrid.borrow_mut();
111			brw.set_data_source(Box::new(ExampleDataSource::default()));
112			//brw.set_radix(Radix::Hexadecimal);
113			brw.set_selection_color(Some(Color::Cyan));
114		}
115
116		Self {
117			uid: WindowUID::new(),
118			datagrid,
119			running: true,
120		}
121	}
pub fn move_selection_up(&mut self)

pub fn move_selection_down(&mut self)

pub fn move_selection_left(&mut self)

pub fn move_selection_right(&mut self)

pub fn move_page_up(&mut self)

pub fn move_page_down(&mut self)

pub fn reevaluate_columns(&mut self)

Should be called when columns or column sizes have been changed

pub fn set_data_source(&mut self, data: Box<dyn DataSource>)

Sets the internal data source

Examples found in repository?
examples/datagrid.rs (line 111)
107	fn default() -> Self {
108		let datagrid = WindowFactory::create::<DataGrid>();
109		{
110			let mut brw = datagrid.borrow_mut();
111			brw.set_data_source(Box::new(ExampleDataSource::default()));
112			//brw.set_radix(Radix::Hexadecimal);
113			brw.set_selection_color(Some(Color::Cyan));
114		}
115
116		Self {
117			uid: WindowUID::new(),
118			datagrid,
119			running: true,
120		}
121	}