DockPanel

Struct DockPanel 

pub struct DockPanel { /* private fields */ }
The center element takes most of the space, but at least 50% in width and height, depending how big the other elements are. The outer elements are technically computed within the layout first and the center is the last one. Each outer element should occupy at most 25% of the width/height - their relative size is relative to the maximum 25%. In case their size is fixed, the heuristic will choose MIN(<fixed window size>, <25% of the dockpanels size>). This control by default has no keybindings.

┌───────────────────────┐
│         Top           │
├──────┬────────┬───────┤
│ Left │ Center │ Right │
├──────┴────────┴───────┤
│        Bottom         │
└───────────────────────┘

Implementations

Source

impl DockPanel

pub const MAX_CHILD_SIZE: Size

The maximum size of an outer (non-center) child element

pub fn new(inner_border: bool) -> Self

pub fn default_callback(_: &mut Self)

pub fn default_key_handler(&mut self, _: &mut WindowEvent)

pub fn set_selection_changed_callback<F: Fn(&mut Self) + 'static>( &mut self, callback: F, )

pub fn set_key_handler(&mut self, f: DockPanelKeyHandler)

pub fn set_inner_border(&mut self, inner_border: bool)

Examples found in repository?
examples/dockpanel.rs (line 50)
30	fn default() -> Self {
31		let label = WindowFactory::create::<Label>();
32		label.borrow_mut().set_text("Lorem ipsum");
33		let label2 = WindowFactory::create::<Label>();
34		label2.borrow_mut().set_text("Bibsum loram");
35		let label3 = WindowFactory::create::<Label>();
36		label3.borrow_mut().set_text("Epsum larel");
37		let label4 = WindowFactory::create::<Label>();
38		label4.borrow_mut().set_text("Ipsel Aarel");
39		let input = WindowFactory::create::<Textbox>();
40
41		let dockpanel = WindowFactory::create::<DockPanel>();
42		{
43			let mut brw = dockpanel.borrow_mut();
44			brw.set_child(DockAlignment::Center, Some(input));
45			brw.set_child(DockAlignment::Top, Some(label));
46			brw.set_child(DockAlignment::Right, Some(label2));
47			brw.set_child(DockAlignment::Left, Some(label3));
48			brw.set_child(DockAlignment::Bottom, Some(label4));
49			brw.set_border(BorderStyle::new(BorderKind::Dashed, None, None));
50			brw.set_inner_border(true);
51		}
52
53		Self {
54			uid: WindowUID::new(),
55			dockpanel,
56			running: true,
57		}
58	}
pub fn set_child(&mut self, dock: DockAlignment, child: Option<WindowRef>)

Examples found in repository?
examples/dockpanel.rs (line 44)
30	fn default() -> Self {
31		let label = WindowFactory::create::<Label>();
32		label.borrow_mut().set_text("Lorem ipsum");
33		let label2 = WindowFactory::create::<Label>();
34		label2.borrow_mut().set_text("Bibsum loram");
35		let label3 = WindowFactory::create::<Label>();
36		label3.borrow_mut().set_text("Epsum larel");
37		let label4 = WindowFactory::create::<Label>();
38		label4.borrow_mut().set_text("Ipsel Aarel");
39		let input = WindowFactory::create::<Textbox>();
40
41		let dockpanel = WindowFactory::create::<DockPanel>();
42		{
43			let mut brw = dockpanel.borrow_mut();
44			brw.set_child(DockAlignment::Center, Some(input));
45			brw.set_child(DockAlignment::Top, Some(label));
46			brw.set_child(DockAlignment::Right, Some(label2));
47			brw.set_child(DockAlignment::Left, Some(label3));
48			brw.set_child(DockAlignment::Bottom, Some(label4));
49			brw.set_border(BorderStyle::new(BorderKind::Dashed, None, None));
50			brw.set_inner_border(true);
51		}
52
53		Self {
54			uid: WindowUID::new(),
55			dockpanel,
56			running: true,
57		}
58	}
pub fn set_focus(&mut self, dock: DockAlignment)