pub struct ScrollBase {
pub offset: Vector2D<usize>,
pub viewport: Vector2D<usize>,
pub render_size: TPoint,
pub scroll_viewer: Weak<RefCell<ScrollViewer>>,
}Expand description
Base struct for storing different information required for the Scrollable trait Has all fns of Scrollable but doesn’t implement the trait
Fields
offset: Vector2D<usize>Offset of the base 0,0 coordinate (as in rendering)
viewport: Vector2D<usize>Viewport for the whole content to be rendered
render_size: TPointActual size rendered
scroll_viewer: Weak<RefCell<ScrollViewer>>Weak reference to the owning scroll viewer
Implementations
Sourceimpl ScrollBase
impl ScrollBase
pub fn is_scrollable(&self, axis: Orientation) -> bool
pub fn scroll(&mut self, direction: Direction, kind: ScrollKind)
pub fn set_offset(&mut self, direction: Orientation, offset: usize)
pub fn offset(&self, axis: Orientation) -> usize
pub fn viewport(&self, axis: Orientation) -> usize
pub fn set_scroll_viewer(&mut self, scroll_viewer: Weak<RefCell<ScrollViewer>>)