pub struct Tab { /* private fields */ }Implementations
Sourceimpl Tab
impl Tab
Sourcepub fn new<S: ToString>(name: S, content: WindowRef) -> Self
pub fn new<S: ToString>(name: S, content: WindowRef) -> Self
Creates an unique tab for a window - the name will be shown in the tab itself
Examples found in repository?
examples/tabview.rs (line 47)
31 fn default() -> Self {
32 let label = WindowFactory::create::<Label>();
33 label.borrow_mut().set_text("Lorem ipsum");
34 let label2 = WindowFactory::create::<Label>();
35 label2.borrow_mut().set_text("Bibsum loram");
36 let label3 = WindowFactory::create::<Label>();
37 label3.borrow_mut().set_text("Epsum larel");
38 let label4 = WindowFactory::create::<Label>();
39 label4.borrow_mut().set_text("Ipsel Aarel");
40
41 let tabview = WindowFactory::create::<TabView>();
42 {
43 let mut brw = tabview.borrow_mut();
44 brw.enable_tab_enumeration();
45 brw.set_highlight_fg_color(Some(Color::Grey));
46 brw.set_highlight_bg_color(Some(Color::Blue));
47 brw.add_item(Tab::new("WIP Tab Number. 1", label));
48 brw.add_item(Tab::new("WIP Tab Number. 2", label2));
49 brw.add_item(Tab::new("WIP Tab Number. 3", label3));
50 brw.add_item(Tab::new("WIP Tab Number. 4", label4));
51 }
52
53 Self {
54 uid: WindowUID::new(),
55 tabview,
56 running: true,
57 }
58 }Trait Implementations
Sourceimpl ItemCollection<Tab> for TabView
impl ItemCollection<Tab> for TabView
Sourcefn remove_item(&mut self, item: &Tab)
fn remove_item(&mut self, item: &Tab)
Removes an item from the underlying collection
Sourcefn remove_at(&mut self, index: Self::Index) -> Tab
fn remove_at(&mut self, index: Self::Index) -> Tab
Removes an item at the given index from the underlying collection
Might panic if index is invalid
Sourcefn get_item(&mut self, index: Self::Index) -> Option<&Tab>
fn get_item(&mut self, index: Self::Index) -> Option<&Tab>
Returns an item from the collection by its index
Sourcefn clear_items(&mut self)
fn clear_items(&mut self)
Clears all items in the underlying collection