TabView

Struct TabView 

pub struct TabView { /* private fields */ }
The currently selected tab will have a highlighted background. All others will have the same background (which is usually darker).

Design:

[1] Tab│[2] Tab│[3] Tab│...

        -------------
        Tab 1 content
        -------------

Implementations

Source

impl TabView

pub const TAB_SEPERATOR: Grapheme

pub const BRACKET_OPEN: Grapheme

pub const BRACKET_CLOSE: Grapheme

pub const ANGLES_RIGHT: Grapheme

pub const ANGLES_LEFT: Grapheme

pub const MIN_TAB_WIDTH: TSize = 4

pub fn default_callback(&mut self)

pub fn default_key_handler(&mut self, event: &mut WindowEvent)

pub fn set_selection_changed_callback<F: Fn(&mut Self) + 'static>( &mut self, callback: F, )

pub fn set_key_handler(&mut self, f: TabViewKeyHandler)

pub fn select_tab(&mut self, tab: &Tab)

Forcibly selects the given tab item

pub fn enable_tab_enumeration(&mut self)

This will enumerate each tab depending on the order they are in Enumerated Tabs will start with (n), n ∈ ℕ

Examples found in repository?
examples/tabview.rs (line 44)
31	fn default() -> Self {
32		let label = WindowFactory::create::<Label>();
33		label.borrow_mut().set_text("Lorem ipsum");
34		let label2 = WindowFactory::create::<Label>();
35		label2.borrow_mut().set_text("Bibsum loram");
36		let label3 = WindowFactory::create::<Label>();
37		label3.borrow_mut().set_text("Epsum larel");
38		let label4 = WindowFactory::create::<Label>();
39		label4.borrow_mut().set_text("Ipsel Aarel");
40
41		let tabview = WindowFactory::create::<TabView>();
42		{
43			let mut brw = tabview.borrow_mut();
44			brw.enable_tab_enumeration();
45			brw.set_highlight_fg_color(Some(Color::Grey));
46			brw.set_highlight_bg_color(Some(Color::Blue));
47			brw.add_item(Tab::new("WIP Tab Number. 1", label));
48			brw.add_item(Tab::new("WIP Tab Number. 2", label2));
49			brw.add_item(Tab::new("WIP Tab Number. 3", label3));
50			brw.add_item(Tab::new("WIP Tab Number. 4", label4));
51		}
52
53		Self {
54			uid: WindowUID::new(),
55			tabview,
56			running: true,
57		}
58	}
pub fn disable_tab_enumeration(&mut self)

Disables the tab enumeration of all tabs

pub fn get_selection(&self) -> Option<&Tab>

Returns the selected Tab

pub fn set_highlight_fg_color(&mut self, color: Option<Color>)

Sets the foreground for the highlighted tab

Examples found in repository?
examples/tabview.rs (line 45)
31	fn default() -> Self {
32		let label = WindowFactory::create::<Label>();
33		label.borrow_mut().set_text("Lorem ipsum");
34		let label2 = WindowFactory::create::<Label>();
35		label2.borrow_mut().set_text("Bibsum loram");
36		let label3 = WindowFactory::create::<Label>();
37		label3.borrow_mut().set_text("Epsum larel");
38		let label4 = WindowFactory::create::<Label>();
39		label4.borrow_mut().set_text("Ipsel Aarel");
40
41		let tabview = WindowFactory::create::<TabView>();
42		{
43			let mut brw = tabview.borrow_mut();
44			brw.enable_tab_enumeration();
45			brw.set_highlight_fg_color(Some(Color::Grey));
46			brw.set_highlight_bg_color(Some(Color::Blue));
47			brw.add_item(Tab::new("WIP Tab Number. 1", label));
48			brw.add_item(Tab::new("WIP Tab Number. 2", label2));
49			brw.add_item(Tab::new("WIP Tab Number. 3", label3));
50			brw.add_item(Tab::new("WIP Tab Number. 4", label4));
51		}
52
53		Self {
54			uid: WindowUID::new(),
55			tabview,
56			running: true,
57		}
58	}
pub fn set_highlight_bg_color(&mut self, color: Option<Color>)

Sets the background for the highlighted tab

Examples found in repository?
examples/tabview.rs (line 46)
31	fn default() -> Self {
32		let label = WindowFactory::create::<Label>();
33		label.borrow_mut().set_text("Lorem ipsum");
34		let label2 = WindowFactory::create::<Label>();
35		label2.borrow_mut().set_text("Bibsum loram");
36		let label3 = WindowFactory::create::<Label>();
37		label3.borrow_mut().set_text("Epsum larel");
38		let label4 = WindowFactory::create::<Label>();
39		label4.borrow_mut().set_text("Ipsel Aarel");
40
41		let tabview = WindowFactory::create::<TabView>();
42		{
43			let mut brw = tabview.borrow_mut();
44			brw.enable_tab_enumeration();
45			brw.set_highlight_fg_color(Some(Color::Grey));
46			brw.set_highlight_bg_color(Some(Color::Blue));
47			brw.add_item(Tab::new("WIP Tab Number. 1", label));
48			brw.add_item(Tab::new("WIP Tab Number. 2", label2));
49			brw.add_item(Tab::new("WIP Tab Number. 3", label3));
50			brw.add_item(Tab::new("WIP Tab Number. 4", label4));
51		}
52
53		Self {
54			uid: WindowUID::new(),
55			tabview,
56			running: true,
57		}
58	}
pub fn select_next(&mut self)

pub fn select_previous(&mut self)