pub struct Textbox { /* private fields */ }Expand description
Single-line text input method Allows navigating through the string, removing (using Backspace) and adding characters at the ‘_’ sign The cursor will hide the grapheme behind it
Design (including Border):
┌─────┐
│Tex_1│
└─────┘Implementations
Sourceimpl Textbox
impl Textbox
pub const DELAY_DEFAULT: Duration
pub const CURSOR: Grapheme
pub const CURSOR_WIDE: Grapheme
pub fn default_callback(_: &mut Self)
pub fn default_key_handler(&mut self, event: &mut WindowEvent)
pub fn set_text_changed_callback<F: Fn(&mut Self) + 'static>( &mut self, callback: F, )
pub fn set_callback_delay(&mut self, duration: Duration)
pub fn set_key_handler(&mut self, f: TextboxKeyHandler)
Sourcepub fn set_cursor_type(&mut self, fat_cursor: bool)
pub fn set_cursor_type(&mut self, fat_cursor: bool)
fat_cursor: true will just highlight the current position, false will use _ instead
as cursor
Sourcepub fn set_focus_color(&mut self, focus_color: Option<Color>)
pub fn set_focus_color(&mut self, focus_color: Option<Color>)
Foreground color when the textbox has focus
pub fn is_readonly(&self) -> bool
pub fn set_readonly(&mut self, readonly: bool)
Sourcepub fn get_max_length(&self) -> usize
pub fn get_max_length(&self) -> usize
Returns the maximum length of the inner text
Sourcepub fn set_max_length(&mut self, length: usize)
pub fn set_max_length(&mut self, length: usize)
Sets the maximum length of the inner text (number of graphemes)
pub fn move_cursor_left(&mut self)
pub fn move_cursor_right(&mut self)
pub fn remove_glyph_before_cursor(&mut self)
pub fn insert_char_at_cursor(&mut self, ch: char)