DataRow

Trait DataRow 

pub trait DataRow {
    // Required method
    fn get_data<'a>(&'a self, column: usize) -> Option<DataValue<'a>>;
}

Required Methods

fn get_data<'a>(&'a self, column: usize) -> Option<DataValue<'a>>

Returns the data of the cell This will return None when the internal value is not set (NULL) or the column doesn’t exist

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors