SubWindowBuilder

Struct SubWindowBuilder 

pub struct SubWindowBuilder { /* private fields */ }

Implementations

Source

impl SubWindowBuilder

pub fn enable_overlapping(&mut self)

Allows overlapping sub-windows Enabled by default

pub fn disable_overlapping(&mut self)

Disallows overlapping sub-windows

pub fn add_child(&mut self, child: WindowRef)

Adds only a new children into the buffer

pub fn add_rect(&mut self, rect: Rect) -> Result<(), RectsOverlapping>

Returns Err when rects overlap (if overlapping is disabled)

pub fn add_pair( &mut self, child: WindowRef, rect: Option<Rect>, ) -> Result<(), RectsOverlapping>

If rect is None then Self::base_rect will be used Returns Err when rects overlap (if overlapping is disabled)

Examples found in repository?
examples/tabview.rs (line 73)
72	fn children(&mut self, mut builder: SubWindowBuilder) -> SubWindows {
73		builder.add_pair(self.tabview.clone(), None).ok();
74		builder.build().unwrap()
75	}
More examples
Hide additional examples
examples/datagrid.rs (line 136)
135	fn children(&mut self, mut builder: SubWindowBuilder) -> SubWindows {
136		builder.add_pair(self.datagrid.clone(), None).ok();
137		builder.build().unwrap()
138	}
examples/dockpanel.rs (line 73)
72	fn children(&mut self, mut builder: SubWindowBuilder) -> SubWindows {
73		builder.add_pair(self.dockpanel.clone(), None).ok();
74		builder.build().unwrap()
75	}
examples/stackpanel.rs (line 42)
41	fn children(&mut self, mut builder: SubWindowBuilder) -> SubWindows {
42		builder.add_pair(self.stackpanel.clone(), None).ok();
43		builder.build().unwrap()
44	}
examples/scrollviewer.rs (line 43)
42	fn children(&mut self, mut builder: SubWindowBuilder) -> SubWindows {
43		builder.add_pair(self.scrollviewer.clone(), None).ok();
44		builder.build().unwrap()
45	}
pub fn base_rect(&self) -> Rect

pub fn build(self) -> Option<SubWindows>

Builds children and their corresponding rects together Children and their rects have to be in the same order Returns None when the children and rects length are unequal

Examples found in repository?
examples/tabview.rs (line 74)
72	fn children(&mut self, mut builder: SubWindowBuilder) -> SubWindows {
73		builder.add_pair(self.tabview.clone(), None).ok();
74		builder.build().unwrap()
75	}
More examples
Hide additional examples
examples/datagrid.rs (line 137)
135	fn children(&mut self, mut builder: SubWindowBuilder) -> SubWindows {
136		builder.add_pair(self.datagrid.clone(), None).ok();
137		builder.build().unwrap()
138	}
examples/dockpanel.rs (line 74)
72	fn children(&mut self, mut builder: SubWindowBuilder) -> SubWindows {
73		builder.add_pair(self.dockpanel.clone(), None).ok();
74		builder.build().unwrap()
75	}
examples/stackpanel.rs (line 43)
41	fn children(&mut self, mut builder: SubWindowBuilder) -> SubWindows {
42		builder.add_pair(self.stackpanel.clone(), None).ok();
43		builder.build().unwrap()
44	}
examples/scrollviewer.rs (line 44)
42	fn children(&mut self, mut builder: SubWindowBuilder) -> SubWindows {
43		builder.add_pair(self.scrollviewer.clone(), None).ok();
44		builder.build().unwrap()
45	}