Struct WindowEvent
Source pub struct WindowEvent {
pub handled: bool,
}
Event wrapper with some additional information used by this library
handled: bool
127 fn handle_event(&mut self, event: &mut WindowEvent) {
128 if let Event::Key(k) = event.raw() {
129 if k.code == KeyCode::Esc {
130 self.running = false;
131 }
132 }
133 }
More examples
Hide additional examples
64 fn handle_event(&mut self, event: &mut WindowEvent) {
65 if let Event::Key(k) = event.raw() {
66 if k.code == KeyCode::Esc {
67 self.running = false;
68 }
69 }
70 }
33 fn handle_event(&mut self, event: &mut WindowEvent) {
34 if let Event::Key(k) = event.raw() {
35 if k.code == KeyCode::Esc {
36 self.running = false;
37 }
38 }
39 }
64 fn handle_event(&mut self, event: &mut WindowEvent) {
65 if let Event::Key(k) = event.raw() {
66 if k.code == KeyCode::Esc {
67 self.running = false;
68 }
69 }
70 }
33 fn handle_event(&mut self, event: &mut WindowEvent) {
34 if let Event::Key(k) = event.raw() {
35 if k.code == KeyCode::Esc {
36 self.running = false;
37 event.handled = true;
38 }
39 }
40 }
Formats the value using the given formatter.
Read more
Gets the type name of self
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns
true if the boxed type is the same as
T.
Read more
Forward to the method defined on the type Any.
Forward to the method defined on the type Any.
Returns the argument unchanged.
A constant of the type witness
Proof that Self is the same type as Self::Type,
provides methods for casting between Self and Self::Type.
The same type as Self,
used to emulate type equality bounds (T == U)
with associated type equality constraints
(T: Identity<Type = U>).
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.