pub type CustomStyleFn = fn(&dyn Window, BorderCanvas<'_>);Expand description
The given Window is the instance which returned BorderStyle
pub type CustomStyleFn = fn(&dyn Window, BorderCanvas<'_>);The given Window is the instance which returned BorderStyle