Numeric

Struct Numeric 

pub struct Numeric { /* private fields */ }
Numerical Up/Down component, where a number can be changed by stepping up or down with a given stepcount Design:

-128▼▲

Implementations

Source

impl Numeric

pub const ARROW_UP: Grapheme = ScrollViewer::ARROW_UP

pub const ARROW_DOWN: Grapheme = ScrollViewer::ARROW_DOWN

pub const ARROW_UP_DISABLED: Grapheme = ScrollViewer::ARROW_UP_DISABLED

pub const ARROW_DOWN_DISABLED: Grapheme = ScrollViewer::ARROW_DOWN_DISABLED

pub const NUMERIC_PLACEHOLDER: Grapheme

pub fn default_key_handler(&mut self, event: &mut WindowEvent)

pub fn default_callback(_: &mut Self)

pub fn set_changed_value_callback<F: Fn(&mut Numeric) + 'static>( &mut self, callback: F, )

pub fn set_key_handler(&mut self, f: NumericKeyHandler)

pub fn set_min_range(&mut self, min_range: i32)

Examples found in repository?
examples/stackpanel.rs (line 68)
52	fn default() -> Self {
53		let label = WindowFactory::create::<Label>();
54		label
55			.borrow_mut()
56			.set_text("Please enter a valid number (x ∈ ℕ):");
57		let button = WindowFactory::create::<Button>();
58		button.borrow_mut().set_text("Press to increment:");
59		button.borrow_mut().set_border(BorderKind::Solid.into());
60		let mut cb: Combobox<u8> = Combobox::default();
61		for v in [1, 2, 4] {
62			cb.add_item(DisplayValue::new(v, format!("Increment by {}", v)));
63		}
64		let cb = Rc::new(RefCell::new(cb));
65		let combobox = cb.clone();
66		let numeric = WindowFactory::create::<Numeric>();
67		numeric.borrow_mut().set_base(Radix::Hexadecimal);
68		numeric.borrow_mut().set_min_range(8);
69		numeric.borrow_mut().set_max_range(64);
70		numeric.borrow_mut().set_focus_color(Some(Color::Cyan));
71		let nc = numeric.clone();
72		combobox
73			.borrow_mut()
74			.set_selection_changed_callback(move |cb| {
75				let mut brw = nc.borrow_mut();
76				brw.set_stepcount(*cb.get_value().unwrap().value())
77			});
78
79		let stackpanel = WindowFactory::create::<Stackpanel>();
80		stackpanel.borrow_mut().set_border(BorderKind::Solid.into());
81		stackpanel.borrow_mut().add_item(label);
82		stackpanel.borrow_mut().add_item(numeric);
83		stackpanel.borrow_mut().add_item(cb);
84
85		Self {
86			uid: WindowUID::new(),
87			stackpanel,
88			running: true,
89		}
90	}
pub fn set_max_range(&mut self, max_range: i32)

Examples found in repository?
examples/stackpanel.rs (line 69)
52	fn default() -> Self {
53		let label = WindowFactory::create::<Label>();
54		label
55			.borrow_mut()
56			.set_text("Please enter a valid number (x ∈ ℕ):");
57		let button = WindowFactory::create::<Button>();
58		button.borrow_mut().set_text("Press to increment:");
59		button.borrow_mut().set_border(BorderKind::Solid.into());
60		let mut cb: Combobox<u8> = Combobox::default();
61		for v in [1, 2, 4] {
62			cb.add_item(DisplayValue::new(v, format!("Increment by {}", v)));
63		}
64		let cb = Rc::new(RefCell::new(cb));
65		let combobox = cb.clone();
66		let numeric = WindowFactory::create::<Numeric>();
67		numeric.borrow_mut().set_base(Radix::Hexadecimal);
68		numeric.borrow_mut().set_min_range(8);
69		numeric.borrow_mut().set_max_range(64);
70		numeric.borrow_mut().set_focus_color(Some(Color::Cyan));
71		let nc = numeric.clone();
72		combobox
73			.borrow_mut()
74			.set_selection_changed_callback(move |cb| {
75				let mut brw = nc.borrow_mut();
76				brw.set_stepcount(*cb.get_value().unwrap().value())
77			});
78
79		let stackpanel = WindowFactory::create::<Stackpanel>();
80		stackpanel.borrow_mut().set_border(BorderKind::Solid.into());
81		stackpanel.borrow_mut().add_item(label);
82		stackpanel.borrow_mut().add_item(numeric);
83		stackpanel.borrow_mut().add_item(cb);
84
85		Self {
86			uid: WindowUID::new(),
87			stackpanel,
88			running: true,
89		}
90	}
pub fn set_value(&mut self, value: i32)

pub fn get_value(&self) -> i32

pub fn set_base(&mut self, base: Radix)

Examples found in repository?
examples/stackpanel.rs (line 67)
52	fn default() -> Self {
53		let label = WindowFactory::create::<Label>();
54		label
55			.borrow_mut()
56			.set_text("Please enter a valid number (x ∈ ℕ):");
57		let button = WindowFactory::create::<Button>();
58		button.borrow_mut().set_text("Press to increment:");
59		button.borrow_mut().set_border(BorderKind::Solid.into());
60		let mut cb: Combobox<u8> = Combobox::default();
61		for v in [1, 2, 4] {
62			cb.add_item(DisplayValue::new(v, format!("Increment by {}", v)));
63		}
64		let cb = Rc::new(RefCell::new(cb));
65		let combobox = cb.clone();
66		let numeric = WindowFactory::create::<Numeric>();
67		numeric.borrow_mut().set_base(Radix::Hexadecimal);
68		numeric.borrow_mut().set_min_range(8);
69		numeric.borrow_mut().set_max_range(64);
70		numeric.borrow_mut().set_focus_color(Some(Color::Cyan));
71		let nc = numeric.clone();
72		combobox
73			.borrow_mut()
74			.set_selection_changed_callback(move |cb| {
75				let mut brw = nc.borrow_mut();
76				brw.set_stepcount(*cb.get_value().unwrap().value())
77			});
78
79		let stackpanel = WindowFactory::create::<Stackpanel>();
80		stackpanel.borrow_mut().set_border(BorderKind::Solid.into());
81		stackpanel.borrow_mut().add_item(label);
82		stackpanel.borrow_mut().add_item(numeric);
83		stackpanel.borrow_mut().add_item(cb);
84
85		Self {
86			uid: WindowUID::new(),
87			stackpanel,
88			running: true,
89		}
90	}
pub fn get_base(&self) -> Radix

pub fn step_up(&mut self)

pub fn step_down(&mut self)

pub fn get_stepcount(&self) -> u8

pub fn set_stepcount(&mut self, stepcount: u8)

Examples found in repository?
examples/stackpanel.rs (line 76)
52	fn default() -> Self {
53		let label = WindowFactory::create::<Label>();
54		label
55			.borrow_mut()
56			.set_text("Please enter a valid number (x ∈ ℕ):");
57		let button = WindowFactory::create::<Button>();
58		button.borrow_mut().set_text("Press to increment:");
59		button.borrow_mut().set_border(BorderKind::Solid.into());
60		let mut cb: Combobox<u8> = Combobox::default();
61		for v in [1, 2, 4] {
62			cb.add_item(DisplayValue::new(v, format!("Increment by {}", v)));
63		}
64		let cb = Rc::new(RefCell::new(cb));
65		let combobox = cb.clone();
66		let numeric = WindowFactory::create::<Numeric>();
67		numeric.borrow_mut().set_base(Radix::Hexadecimal);
68		numeric.borrow_mut().set_min_range(8);
69		numeric.borrow_mut().set_max_range(64);
70		numeric.borrow_mut().set_focus_color(Some(Color::Cyan));
71		let nc = numeric.clone();
72		combobox
73			.borrow_mut()
74			.set_selection_changed_callback(move |cb| {
75				let mut brw = nc.borrow_mut();
76				brw.set_stepcount(*cb.get_value().unwrap().value())
77			});
78
79		let stackpanel = WindowFactory::create::<Stackpanel>();
80		stackpanel.borrow_mut().set_border(BorderKind::Solid.into());
81		stackpanel.borrow_mut().add_item(label);
82		stackpanel.borrow_mut().add_item(numeric);
83		stackpanel.borrow_mut().add_item(cb);
84
85		Self {
86			uid: WindowUID::new(),
87			stackpanel,
88			running: true,
89		}
90	}
pub fn set_focus_color(&mut self, color: Option<Color>)

Examples found in repository?
examples/stackpanel.rs (line 70)
52	fn default() -> Self {
53		let label = WindowFactory::create::<Label>();
54		label
55			.borrow_mut()
56			.set_text("Please enter a valid number (x ∈ ℕ):");
57		let button = WindowFactory::create::<Button>();
58		button.borrow_mut().set_text("Press to increment:");
59		button.borrow_mut().set_border(BorderKind::Solid.into());
60		let mut cb: Combobox<u8> = Combobox::default();
61		for v in [1, 2, 4] {
62			cb.add_item(DisplayValue::new(v, format!("Increment by {}", v)));
63		}
64		let cb = Rc::new(RefCell::new(cb));
65		let combobox = cb.clone();
66		let numeric = WindowFactory::create::<Numeric>();
67		numeric.borrow_mut().set_base(Radix::Hexadecimal);
68		numeric.borrow_mut().set_min_range(8);
69		numeric.borrow_mut().set_max_range(64);
70		numeric.borrow_mut().set_focus_color(Some(Color::Cyan));
71		let nc = numeric.clone();
72		combobox
73			.borrow_mut()
74			.set_selection_changed_callback(move |cb| {
75				let mut brw = nc.borrow_mut();
76				brw.set_stepcount(*cb.get_value().unwrap().value())
77			});
78
79		let stackpanel = WindowFactory::create::<Stackpanel>();
80		stackpanel.borrow_mut().set_border(BorderKind::Solid.into());
81		stackpanel.borrow_mut().add_item(label);
82		stackpanel.borrow_mut().add_item(numeric);
83		stackpanel.borrow_mut().add_item(cb);
84
85		Self {
86			uid: WindowUID::new(),
87			stackpanel,
88			running: true,
89		}
90	}