pub struct Stackpanel { /* private fields */ }Expand description
Stackpanel will group multiple windows and arrange them according to the Orientation. It will also allow movement between them using the arrow keys. Default margin is 1.
Design (optional Border, vertical):
┌─────────┐
│Content A│
│ │
│Content B│
└─────────┘Horizontal:
┌─────────────────────┐
│Content A Content B│
└─────────────────────┘Implementations
Sourceimpl Stackpanel
impl Stackpanel
pub fn default_callback(_: &mut Self)
pub fn default_key_handler(&mut self, event: &mut WindowEvent)
Sourcepub fn new(orientation: Orientation) -> Self
pub fn new(orientation: Orientation) -> Self
Constructs a new Stackpanel with the given Orientation
pub fn set_selection_changed_callback<F: Fn(&mut Self) + 'static>( &mut self, callback: F, )
pub fn set_key_handler(&mut self, f: StackpanelKeyHandler)
Sourcepub fn set_item_alignment(&mut self, alignment: Alignment)
pub fn set_item_alignment(&mut self, alignment: Alignment)
Sets the alignment for each child/item within the Stackpanel
pub fn set_orientation(&mut self, orientation: Orientation)
Sourcepub fn set_child_margin(&mut self, margin: u8)
pub fn set_child_margin(&mut self, margin: u8)
Sets the offset between each child
Sourcepub fn scroll(
&mut self,
direction: Direction,
kind: ScrollKind,
scroll_only: bool,
)
pub fn scroll( &mut self, direction: Direction, kind: ScrollKind, scroll_only: bool, )
scroll_only specifies whether selection should also change if only the view changes
pub fn has_scroll_viewer(&self) -> bool