pub struct SubWindowBuilder { /* private fields */ }Implementations
Sourceimpl SubWindowBuilder
impl SubWindowBuilder
Sourcepub fn enable_overlapping(&mut self)
pub fn enable_overlapping(&mut self)
Allows overlapping sub-windows Enabled by default
Sourcepub fn disable_overlapping(&mut self)
pub fn disable_overlapping(&mut self)
Disallows overlapping sub-windows
Sourcepub fn add_rect(&mut self, rect: Rect) -> Result<(), RectsOverlapping>
pub fn add_rect(&mut self, rect: Rect) -> Result<(), RectsOverlapping>
Returns Err when rects overlap (if overlapping is disabled)
Sourcepub fn add_pair(
&mut self,
child: WindowRef,
rect: Option<Rect>,
) -> Result<(), RectsOverlapping>
pub fn add_pair( &mut self, child: WindowRef, rect: Option<Rect>, ) -> Result<(), RectsOverlapping>
If rect is None then Self::base_rect will be used
Returns Err when rects overlap (if overlapping is disabled)
Examples found in repository?
More examples
pub fn base_rect(&self) -> Rect
Sourcepub fn build(self) -> Option<SubWindows>
pub fn build(self) -> Option<SubWindows>
Builds children and their corresponding rects together
Children and their rects have to be in the same order
Returns None when the children and rects length are unequal
Examples found in repository?
More examples